@@ -1,6 +1,6 @@
 from __future__ import unicode_literals
 
-from typing import TYPE_CHECKING, List, Optional, Text, Tuple, overload
+from typing import TYPE_CHECKING, List, Optional, Text, Tuple, Union, overload
 
 import attr
 from selenium.webdriver.common.by import By
@@ -11,6 +11,7 @@ from applitools.common.geometry import AccessibilityRegion, Region
 from applitools.common.ultrafastgrid import VisualGridOption
 from applitools.common.utils import argument_guard
 from applitools.common.utils.compat import basestring
+from applitools.common.utils.json_utils import JsonInclude
 from applitools.core.fluent import CheckSettings, CheckSettingsValues
 from applitools.selenium.validators import is_list_or_tuple, is_webelement
 from applitools.selenium.webelement import EyesWebElement
@@ -53,18 +54,41 @@ class FrameLocator(object):
 @attr.s
 class SeleniumCheckSettingsValues(CheckSettingsValues):
     # hide_caret = attr.ib(init=False, default=None)
-    scroll_root_element = attr.ib(init=False, default=None)  # type: EyesWebElement
-    scroll_root_selector = attr.ib(init=False, default=None)  # type: CssSelector
-    target_selector = attr.ib(init=False, default=None)  # type: BySelector
-    target_element = attr.ib(init=False, default=None)  # type: EyesWebElement
-    frame_chain = attr.ib(init=False, factory=list)  # type: List[FrameLocator]
+    scroll_root_element = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, init=False, default=None
+    )  # type: EyesWebElement
+    scroll_root_selector = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, init=False, default=None
+    )  # type: CssSelector
+    target_selector = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, init=False, default=None
+    )  # type: BySelector
+    target_element = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, init=False, default=None
+    )  # type: EyesWebElement
+    frame_chain = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, init=False, factory=list
+    )  # type: List[FrameLocator]
 
     # for Rendering Grid
-    selector = attr.ib(default=None)  # type: VisualGridSelector
-    script_hooks = attr.ib(factory=dict)  # type: dict
-    visual_grid_options = attr.ib(default=())  # type: Tuple[VisualGridOption]
-    disable_browser_fetching = attr.ib(default=None)  # type: Optional[bool]
-    ocr_region = attr.ib(init=False, default=None)  # type: Optional[OCRRegion]
+    selector = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=None
+    )  # type: VisualGridSelector
+    script_hooks = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, factory=dict
+    )  # type: dict
+    visual_grid_options = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=()
+    )  # type: Tuple[VisualGridOption]
+    disable_browser_fetching = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=None
+    )  # type: Optional[bool]
+    ocr_region = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, init=False, default=None
+    )  # type: Optional[OCRRegion]
+    layout_breakpoints = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=None
+    )  # type: Optional[Union[bool, List[int]]]
 
     @property
     def size_mode(self):
@@ -437,6 +461,27 @@ class SeleniumCheckSettings(CheckSettings):
         self.values.disable_browser_fetching = disable
         return self
 
+    @overload
+    def layout_breakpoints(self, enabled):
+        # type: (bool) -> SeleniumCheckSettings
+        pass
+
+    @overload
+    def layout_breakpoints(self, *breakpoints):
+        # type: (*int) -> SeleniumCheckSettings
+        pass
+
+    def layout_breakpoints(self, enabled_or_first, *rest):
+        if isinstance(enabled_or_first, bool):
+            self.values.layout_breakpoints = enabled_or_first
+        elif isinstance(enabled_or_first, int):
+            self.values.layout_breakpoints = [enabled_or_first] + list(rest)
+        else:
+            raise TypeError(
+                "{} is not an instance of bool or int".format(enabled_or_first)
+            )
+        return self
+
     @property
     def is_check_window(self):
         # type: () -> bool
